@@ -1,3 +1,5 @@
+from pathlib import Path
+import os
 import logging
 import sys
 import importlib
@@ -61,6 +63,8 @@ class CustomParser(argparse.ArgumentParser):
         if self.DEFAULT_ENTRY_POINT:
             entry_point_help = ('Entry point, defaults '
                                 f'to {self.DEFAULT_ENTRY_POINT}')
+            if os.environ.get('ENTRY_POINT'):
+                entry_point_help += ' (ENTRY_POINT env var)'
         else:
             entry_point_help = 'Entry point'
 
@@ -341,7 +345,9 @@ def _process_file_dir_or_glob(parser, dagspec_arg=None):
         path_to_env = default.path_to_env_from_spec(entry_point_value)
 
     if path_to_env:
-        env_dict = EnvDict(path_to_env)
+        env_dict = EnvDict(path_to_env,
+                           path_to_here=Path(entry_point_value).parent
+                           if entry.type == EntryPoint.File else None)
         _add_cli_args_from_env_dict_keys(parser, env_dict)
 
     args = parser.parse_args()
