@@ -1,15 +1,15 @@
-from ploomber.spec.dagspec import DAGSpec
-from ploomber.scaffold.ScaffoldLoader import ScaffoldLoader
+from ploomber.scaffold.scaffoldloader import ScaffoldLoader
 from ploomber.util.util import add_to_sys_path
-from ploomber.exceptions import DAGSpecInitializationError
+from ploomber.util import loader
+from ploomber.exceptions import DAGSpecInvalidError
 
 
 def load_dag():
     # setting lazy_import to true causes sources to be returned as paths,
     # instead of placeholders
     try:
-        return DAGSpec._auto_load(to_dag=False, lazy_import=True)
-    except DAGSpecInitializationError:
+        return loader._default_spec_load(lazy_import=True)
+    except DAGSpecInvalidError:
         return None
 
 
