@@ -12,6 +12,7 @@ from ploomber.util import validate, dotted_path
 from ploomber.tasks.taskgroup import TaskGroup
 from ploomber import validators
 from ploomber.exceptions import DAGSpecInitializationError
+from ploomber.products._resources import resolve_resources
 
 suffix2taskclass = {
     '.py': tasks.NotebookRunner,
@@ -45,8 +46,9 @@ def task_class_from_source_str(source_str, lazy_import, reload, product):
     # we verify if this is a valid dotted path
     # if lazy load, just locate the module without importing it
 
-    fn_checker = dotted_path.locate_dotted_path if lazy_import else partial(
-        dotted_path.load_dotted_path, raise_=True, reload=reload)
+    fn_checker = (
+        dotted_path.locate_dotted_path_root if lazy_import else partial(
+            dotted_path.load_dotted_path, raise_=True, reload=reload))
 
     if extension and extension in suffix2taskclass:
         if extension == '.sql' and _safe_suffix(product) in {
@@ -66,10 +68,9 @@ def task_class_from_source_str(source_str, lazy_import, reload, product):
         if imported is None:
             raise ValueError(
                 'Could not determine task class for '
-                f'source {source_str!r}. This looks like a dotted path '
-                'but it failed to import. Original error '
-                f'message: {error!s}. You can also set the task class '
-                'using the "class" key')
+                f'source {source_str!r} due to error: {error!s}.\n\n'
+                'This looks like a dotted path but it failed to import. '
+                'You can also set the task class using the "class" key.')
         else:
             return tasks.PythonCallable
 
@@ -321,6 +322,11 @@ def _init_task(data, meta, project_root, lazy_import, dag):
             and 'check_if_kernel_installed' not in task_dict):
         task_dict['check_if_kernel_installed'] = False
 
+    # make paths to resources absolute
+    if 'params' in task_dict:
+        task_dict['params'] = resolve_resources(task_dict['params'],
+                                                relative_to=project_root)
+
     try:
         task = class_(source=source,
                       product=product,
@@ -380,9 +386,12 @@ def _init_product(task_dict, meta, task_class, root_path, lazy_import):
     else:
         kwargs = {}
 
+    # determine the base path for the product (only relevant if product
+    # is a File)
     relative_to = (Path(task_dict['source']).parent
                    if meta['product_relative_to_source'] else root_path)
 
+    # initialize Product instance
     return try_product_init(CLASS, product_raw, relative_to, kwargs)
 
 
@@ -458,6 +467,8 @@ def validate_product_class_name(product_class_name):
 
 
 def resolve_if_file(product_raw, relative_to, class_):
+    """Resolve Product argument if it's a File to make it an absolute path
+    """
     try:
         return _resolve_if_file(product_raw, relative_to, class_)
     except Exception as e:
@@ -467,8 +478,12 @@ def resolve_if_file(product_raw, relative_to, class_):
 
 
 def _resolve_if_file(product_raw, relative_to, class_):
+    """Resolve File argument to make it an absolute path
+    """
+    # not a file, nothing to do...
     if class_ != products.File:
         return product_raw
+    # resolve...
     elif relative_to:
         # To keep things consistent, product relative paths are so to the
         # pipeline.yaml file (not to the current working directory). This is
@@ -477,6 +492,7 @@ def _resolve_if_file(product_raw, relative_to, class_):
         # when using the integration with Jupyter notebooks, each notebook
         # will set its working directory to the current parent.
         return str(Path(relative_to, product_raw).resolve())
+    # no realtive_to argument, nothing to do...
     else:
         return Path(product_raw).resolve()
 
