@@ -27,7 +27,10 @@ from ploomber.products import MetaProduct, File
 
 
 def _unserializer(product, unserializer):
-    # this happens when we have a task group
+    # this happens when we have a task group. e.g., product declares
+    # 'fit-*' as dependency, which matches fit-1, fit-2, etc. Then product
+    # becomes...
+    # {'fit-*': {'fit-1': product, 'fit-2': another, ...}}
     if isinstance(product, Mapping) and not isinstance(product, MetaProduct):
         return {k: unserializer(p) for k, p in product.items()}
     else:
@@ -114,7 +117,8 @@ class PythonCallable(Task):
             product = params.pop('product')
         else:
             product = params['product']
-            _ensure_parents_exist(product)
+
+        _ensure_parents_exist(product)
 
         # call function
         out = self.source.primitive(**params)
@@ -240,6 +244,10 @@ class PythonCallable(Task):
         **kwargs
             Arguments passed to the unserializer function
         """
+        if isinstance(self.product, MetaProduct) and key is None:
+            raise ValueError(f'Task {self!r} generates multiple products, '
+                             'use the "key" argument to load one')
+
         prod = self.product if not key else self.product[key]
 
         if self._unserializer is not None:
