@@ -202,6 +202,20 @@ def locate_dotted_path(dotted_path):
     return spec
 
 
+def locate_dotted_path_root(dotted_path):
+    """
+    Returns the module spec for a given dotted path.
+    e.g. module.sub.another, checks that module exists
+    """
+    tokens = dotted_path.split('.')
+    spec = importlib.util.find_spec(tokens[0])
+
+    if spec is None:
+        raise ModuleNotFoundError(f'Module {tokens[0]!r} does not exist')
+
+    return spec
+
+
 def _process_children(ch):
     if hasattr(ch, 'name'):
         return [(ch.name.value, ch.type, ch.get_code())]
@@ -236,7 +250,6 @@ def _check_last_definition_is_function(module, name, dotted_path):
 
 
 def _check_defines_function_with_name(path, name, dotted_path):
-
     module = parso.parse(Path(path).read_text())
 
     # there could be multiple with the same name
@@ -268,6 +281,10 @@ def _check_defines_function_with_name(path, name, dotted_path):
     # return the last definition to be consistent with inspect.getsourcefile
     fn_found = fns[-1]
 
+    # if function is decorated, include decorators in the returned source code
+    if fn_found.parent.type == 'decorated':
+        fn_found = fn_found.parent
+
     _check_last_definition_is_function(module, name, dotted_path)
 
     return f'{path}:{fn_found.start_pos[0]}', fn_found.get_code().lstrip()
